==> haskell-th-lift-instances-0.1.11-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-DfO0ODlKMXb7cIttuVGQZc
key: th-lift-instances-0.1.11-DfO0ODlKMXb7cIttuVGQZc
license: BSD3
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
author: Benno Fünfstück
exposed: True
indefinite: False
exposed-modules:
    Instances.TH.Lift
abi: 590dff4e72c5e354a99a6fa1faffe340
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-instances-0.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-DfO0ODlKMXb7cIttuVGQZc
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
    th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q containers-0.5.10.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             th-lift-0.7.8-9WoT75e11sF5vCUkzmby5Q=45860d93836c2d823f47ee3c78d7c61c
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.11-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-3Gmzoq2k9NqCusk4d7tKSk
key: th-lift-instances-0.1.11-3Gmzoq2k9NqCusk4d7tKSk
license: BSD3
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
author: Benno Fünfstück
exposed: True
indefinite: False
exposed-modules:
    Instances.TH.Lift
abi: 663cf124a9400d328ed7f6cc40d61c94
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/th-lift-instances-0.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-3Gmzoq2k9NqCusk4d7tKSk
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
    th-lift-0.7.10-G3XiXDUh4133Q225ueZYGi containers-0.5.10.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             th-lift-0.7.10-G3XiXDUh4133Q225ueZYGi=84d98936d171a4c6838b2f837c12329a
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
